### Name: nSurvival
### Title: 3.3: Time-to-event sample size calculation (Lachin-Foulkes)
### Aliases: nSurvival 'Survival sample size'
### Keywords: design

### ** Examples


# consider a trial with 
# 2 year maximum follow-up
# 6 month uniform enrollment
# Treatment/placebo hazards = 0.1/0.2 per 1 person-year
# drop out hazard 0.1 per 1 person-year
# alpha = 0.05 (two-sided)
# power = 0.9 (default beta=.1)

ss <- nSurvival(lambda.0=.2 , lambda.1=.1, eta = .1, Ts = 2, Tr = .5,
                sided=1, alpha=.025)

#  symmetric, 2-sided design with O'Brien-Fleming-like boundaries
#  sample size is computed based on a fixed design requiring n=100
        x<-gsDesign(k = 5, test.type = 2)
        x
# boundary plot
        plot(x)
# power plot
        plot(x, plottype = 2)
# total sample size
   ceiling(x$n.I[x$k] * ss$Sample.size)
# number of events at analyses
   ceiling(ss$Num.events * x$n.I)



